# frozen_string_literal: true

require 'securerandom'

# /message routes
class Destructo < Sinatra::Base

  get '/message' do
    redirect '/message/new'
  end

  get '/message/new' do
    erb :'message/new', locals: {
      title: 'Create new message'
    }
  end

  post '/message/new' do
    # generate a random string for the slug
    slug = SecureRandom.urlsafe_base64(12)

    # create object in DB
    msg = Message.create(
      slug: slug,
      body: params[:message_body]
    )

    msg_url = message_url(slug)
    flash[:success] = "Your message was created successfully! Share this link: <a href='#{msg_url}'>#{msg_url}</a>"

    redirect '/'
  end

  get '/message/:message_slug' do
    message = Message.where(slug: params[:message_slug]).first()

    if message
      # delete the message
      message.delete()

      erb :'message/view', locals: {
        title: 'View message',
        message: message
      }
    else
      404
    end
  end

end
